Interface OutputHandler
- All Superinterfaces:
StreamVisitor
- All Known Subinterfaces:
TagHandler
- All Known Implementing Classes:
AllTagHandler,BaseTagHandler,RawOutputHandler,StandardTagHandler,StopHandler
Handler that should be used to handle command line output.
Each line is give to the
Each line is give to the
readLine(String) method.
This method should return:
-
trueif next line should be read. For instance, if current line isnull, it probably means that no more output is available. This may let handlers to implement a custom logic. falseif next line should not be read (end of output).
-
Method Summary
-
Method Details
-
readLine
Read a line from command output. Returned value is a boolean: it should indicate if next line should be read or if output is finished.- Specified by:
readLinein interfaceStreamVisitor- Parameters:
line- Line output.- Returns:
- Boolean indicating if next line should be read.
-